// src/node/app/http/polyfills.ts
async function interop(loader, specifier) {
  const mod = await loader();
  return mod[specifier] ?? mod.default[specifier];
}
var globals = {
  crypto: () => import("node:crypto"),
  URLPattern: () => interop(() => import("urlpattern-polyfill"), "URLPattern"),
  Headers: () => interop(() => import("undici"), "Headers"),
  ReadableStream: () => interop(() => import("node:stream/web"), "ReadableStream"),
  TransformStream: () => interop(() => import("node:stream/web"), "TransformStream"),
  WritableStream: () => interop(() => import("node:stream/web"), "WritableStream"),
  Request: async () => {
    const Readable = await interop(() => import("node:stream"), "Readable");
    const Request = await interop(() => import("undici"), "Request");
    const NodeFetchRequest = await interop(
      () => import("node-fetch"),
      "Request"
    );
    return class extends Request {
      formData() {
        return new NodeFetchRequest(this.url, {
          method: this.method,
          headers: this.headers,
          body: this.body && Readable.from(this.body)
        }).formData();
      }
    };
  },
  Response: () => interop(() => import("undici"), "Response"),
  fetch: () => interop(() => import("undici"), "fetch")
};
var installed = false;
async function installPolyfills() {
  if (installed)
    return;
  for (const name in globals) {
    if (!(name in globalThis)) {
      Object.defineProperty(globalThis, name, {
        enumerable: true,
        configurable: true,
        writable: true,
        value: await globals[name]()
      });
    }
  }
  installed = true;
}
export {
  installPolyfills
};
